@@ -805,7 +805,7 @@ def RGBSave(parameter, *args, **kwargs):
             # If array is in (x, y, z) order (cols, rows, bands)
             dst.write(np.moveaxis(nrg, [0, 1, 2], [1, 2, 0]))
 
-        return 'Succeed : ' + parameter['output']
+        return 'successful : ' + parameter['output']
 
     except Exception as e:
         return 'error to save :' + str(e)
@@ -836,7 +836,7 @@ def NDVISave(parameter, *args, **kwargs):
         with rasterio.open(parameter['output'], 'w', **ras_meta) as dst:
             dst.write(ndvi, 1)
 
-        return 'Succeed : ' + parameter['output']
+        return 'successful : ' + parameter['output']
 
     except Exception as e:
         return 'error to save :' + str(e)
@@ -891,7 +891,7 @@ def GraySave(parameter, *args, **kwargs):
         with rasterio.open(parameter['output'], 'w', **ras_meta) as dst:
             dst.write(image, 1)
 
-        return 'Succeed : ' + parameter['output']
+        return 'successful : ' + parameter['output']
 
     except Exception as e:
         print(e)
@@ -1216,7 +1216,7 @@ def ExportCoverage(collection, *args, **kwargs):
                 file.close()
 
             elif fileURL.split(".")[-1] == 'tif' or fileURL.split(".")[-1] == 'tiff' or fileURL.split(".")[-1] == 'TIF':
-                return "succeed store file : " + str(filename)
+                return "successful store file : " + str(filename)
 
             else:
                 pass
@@ -1224,7 +1224,7 @@ def ExportCoverage(collection, *args, **kwargs):
         else:
             return "error : get data failed"
 
-        return "succeed store in folder : " + str(new_folder)
+        return "successful store in folder : " + str(new_folder)
 
     except Exception as e:
         return 'error :' + str(e)
@@ -1241,7 +1241,7 @@ def BandStack(parameter):
         arr_st, meta = es.stack(
             stack_band_paths, out_path=raster_out_path)
 
-        return 'Succeed : ' + parameter['output']
+        return 'successful : ' + parameter['output']
 
     except Exception as e:
         print(e)
@@ -1250,13 +1250,17 @@ def BandStack(parameter):
 
 def CreateCoverage(parameter, *args, **kwargs):
     thumbnail = kwargs.get('thumbnail', [1, 2, 3])
+    mimeType = kwargs.get('mimeType', 'tif')
 
     try:
         Api_Key = os.environ["APIKey"]
         file_in = parameter['data']
         file_get = file_in.split("/")[-1]
 
-        shutil.copy(file_in, file_get)
+        try :
+            shutil.copy(file_in, file_get)
+        except:
+            pass
 
         zip_id = uuid.uuid4().hex
         file_out = zip_id + ".zip"
@@ -1268,7 +1272,7 @@ def CreateCoverage(parameter, *args, **kwargs):
 
         HOST = os.environ["VallarisServer"]
 
-        url = HOST + "/core/api/utilities/1.0/files"
+        url = HOST + "/core/api/managements/1.0/files"
         payload = {'authRequired': 'true',
                    'expiresIn': '1d1h1m1s'
                    }
@@ -1309,7 +1313,7 @@ def CreateCoverage(parameter, *args, **kwargs):
                         thumbnail[2]
                     ]
                 },
-                "mimeType": "tif"
+                "mimeType": mimeType
             }
         })
         headers = {
@@ -1318,6 +1322,7 @@ def CreateCoverage(parameter, *args, **kwargs):
         }
 
         response = requests.request("POST", url, headers=headers, data=payload)
+        # print(payload)
 
         try:
             response_json = response.json()
@@ -1334,7 +1339,7 @@ def CreateCoverage(parameter, *args, **kwargs):
                 "GET", f"{HOST}/core/api/coverages/1.0-beta/manager/import/{collection}/jobs/" + getjobID, headers=headers, data=payload)
             print(
                 f'{str(response_st.json()["status"])} : {str(response_st.json()["progress"])} %')
-            if str(response_st.json()["progress"]) == "100" and response_st.json()["status"] == "succeed":
+            if str(response_st.json()["progress"]) == "100" and response_st.json()["status"] == "successful":
                 status = response_st.json()["status"]
                 break
 
@@ -1345,8 +1350,8 @@ def CreateCoverage(parameter, *args, **kwargs):
         if os.path.exists(zip_id + ".zip"):
             os.remove(zip_id + ".zip")
 
-        if status == "succeed":
-            return 'Succeed : ' + HOST + "/management/studio/coverages/" + collection
+        if status == "successful":
+            return 'successful : ' + HOST + "/management/studio/coverages/" + collection
 
         else:
             return 'error to create coverage : failed'
@@ -1509,7 +1514,7 @@ def CreateCoverageTile(parameter, *args, **kwargs):
                 "GET", f"{HOST}/core/api/coverages/1.0-beta/manager/maketile/{collection_in}/jobs/" + getjobID, headers=headers, data=payload)
             print(
                 f'{str(response_st.json()["status"])} : {str(response_st.json()["progress"])} %')
-            if str(response_st.json()["progress"]) == "100" and response_st.json()["status"] == "succeed":
+            if str(response_st.json()["progress"]) == "100" and response_st.json()["status"] == "successful":
                 status = response_st.json()["status"]
                 break
 
@@ -1517,8 +1522,8 @@ def CreateCoverageTile(parameter, *args, **kwargs):
                 status = response_st.json()["status"]
                 break
 
-        if status == "succeed":
-            return 'Succeed : ' + HOST + "/management/studio/tiles-coverage/" + collection_out
+        if status == "successful":
+            return 'successful : ' + HOST + "/management/studio/tiles-coverage/" + collection_out
 
         else:
             return 'error to create coverage : failed'
